aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/file.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/file.hxx')
-rw-r--r--libbuild2/file.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/libbuild2/file.hxx b/libbuild2/file.hxx
index 231ea73..8af408e 100644
--- a/libbuild2/file.hxx
+++ b/libbuild2/file.hxx
@@ -158,9 +158,10 @@ namespace build2
LIBBUILD2_SYMEXPORT dir_path
bootstrap_fwd (context&, const dir_path& src_root, optional<bool>& altn);
// Bootstrap the project's root scope, the out part.
//
- LIBBUILD2_SYMEXPORT void
+ LIBBUILD2_SYMEXPORT value&
bootstrap_out (scope& root, optional<bool>& altn);
// Bootstrap the project's root scope, the src part. Return true if we
@@ -158,9 +158,10 @@ namespace build2
LIBBUILD2_SYMEXPORT dir_path
bootstrap_fwd (context&, const dir_path& src_root, optional<bool>& altn);
- // Bootstrap the project's root scope, the out part.
+ // Bootstrap the project's root scope, the out part. Return the src_root
+ // variable value (which can be NULL).
//